@@ -38,6 +38,9 @@ class PowerNap:
         self.STAGE2_ACTION_METHOD = 4
         self.MONITORS = []
         self.WARN = False
+        self.WATCH_CONFIG = False
+        self.KERN_MODULES = {}
+        self.SERVICES = {}
         self.stage2_action_enabled = False
         # Load default config file (/etc/powernap/config)
         self.load_config_file()
@@ -104,6 +107,17 @@ class PowerNap:
         if var == "warn":
             if value == "y" or value == "yes":
                 self.WARN = True
+            else:
+                self.WARN = False
+        if var == "watch_config":
+            if value == "y" or value == "yes":
+                self.WATCH_CONFIG = True
+            else:
+                self.WATCH_CONFIG = False
+        if var == "kern_modules":
+            self.KERN_MODULES = value.split()
+        if var == "services":
+            self.SERVICES = value.split()
 
     def set_stage2_values(self, var, value):
         if var == "stage2_action_method":
